/// <reference types="node" />
import { BroadcastOptions, EventBusOptions, EventCenterMessage, IEventBus, Message, PublishOptions, SubscribeOptions } from './interface';
export declare abstract class AbstractEventBus<T> implements IEventBus<T> {
    protected readonly options: EventBusOptions;
    private isInited;
    protected workers: T[];
    protected stopping: boolean;
    private hub;
    protected workerReady: Map<string, {
        worker: T;
        ready: boolean;
    }>;
    private listener;
    private topicListener;
    private asyncMessageMap;
    protected eventListenerMap: Map<string, any>;
    protected debugLogger: import("util").DebugLogger;
    constructor(options?: EventBusOptions);
    private createDebugger;
    private debugDataflow;
    start(): Promise<void>;
    addWorker(worker: T): void;
    private isAllWorkerReady;
    private setupEventBind;
    protected transit(message: EventCenterMessage): void;
    subscribe(listener: (message: Message, callback?: (data: any) => void) => void, options?: SubscribeOptions): void;
    subscribeOnce(listener: (message: Message, callback?: (data: any) => void) => void, options?: SubscribeOptions): void;
    publish(data: unknown, publishOptions?: PublishOptions): void;
    publishAsync(data: unknown, publishOptions?: PublishOptions): Promise<any>;
    broadcast(data: unknown, options?: BroadcastOptions): void;
    protected postMessage(message: Message): void;
    protected abstract workerSubscribeMessage(subscribeMessageHandler: (message: Message) => void): any;
    protected abstract workerListenMessage(worker: T, subscribeMessageHandler: (message: Message) => void): any;
    protected abstract workerSendMessage(message: Message): any;
    protected abstract mainSendMessage(worker: T, message: Message): any;
    abstract isMain(): any;
    abstract isWorker(): any;
    abstract getWorkerId(worker?: T): string;
    onInited(listener: (message: Message<unknown>) => void): void;
    onPublish(listener: (message: Message<unknown>) => void): void;
    onSubscribe(listener: (message: Message<unknown>) => void): void;
    onError(listener: (error: Error) => void): void;
    stop(): Promise<void>;
    generateMessageId(): string;
}
//# sourceMappingURL=base.d.ts.map