export declare const EVENT_MSG_INITED = "message_inited";
export declare const EVENT_MSG_REQUEST = "message_request";
export declare const EVENT_MSG_RESPONSE = "message_response";
export declare const EVENT_MSG_INVOKE = "message_invoke";
export declare const EVENT_MSG_BROADCAST = "message_broadcast";
export declare enum MessageType {
    /**
     * worker => main
     */
    Inited = "inited",
    /**
     * main => worker
     */
    Request = "request",
    /**
     * worker => main
     */
    Response = "response",
    Invoke = "invoke",
    Broadcast = "broadcast"
}
export declare enum ListenerType {
    Inited = "inited",
    Request = "request",
    Subscribe = "Subscribe",
    WorkerChanged = "worker_changed",
    Error = "error"
}
export declare enum MessageCategory {
    IN = "in",
    OUT = "out"
}
export declare type Message<BODY = any> = {
    messageId: string;
    workerId: string;
    type: MessageType;
    error?: {
        stack: string;
    };
    body: BODY;
    messageOptions?: PublishOptions | BroadcastOptions;
};
export declare type EventCenterMessage = {
    messageCategory: MessageCategory;
    message: Message;
};
export interface EventBusOptions {
    initTimeout?: number;
    isWorker?: boolean;
}
export interface PublishOptions {
    timeout?: number;
    relatedMessageId?: string;
    targetWorkerId?: string;
    topic?: string;
}
export interface BroadcastOptions {
    /**
     * default false
     */
    includeSelfFromWorker?: boolean;
    /**
     * default false
     */
    includeMainFromWorker?: boolean;
    relatedMessageId?: string;
    relatedWorkerId?: string;
    topic?: string;
}
export interface SubscribeOptions {
    topic?: string;
    subscribeOnce?: boolean;
}
export declare type SubscribeTopicListener = (message: Message, callback?: (data: any) => void) => void;
export interface IEventBus<T> {
    addWorker(worker: T): any;
    start(): Promise<void>;
    subscribe(callback: (message: Message) => void, options?: SubscribeOptions): any;
    subscribeOnce(callback: (message: Message) => void, options?: SubscribeOptions): any;
    publishAsync(data: unknown, publishOptions?: PublishOptions): Promise<any>;
    publish(data: unknown, publishOptions?: PublishOptions): any;
    broadcast(data: unknown, options?: BroadcastOptions): any;
    isMain(): boolean;
    isWorker(): boolean;
    getWorkerId(worker: T): string;
    stop(): Promise<void>;
    onInited(listener: (message: Message) => void): any;
    onPublish(listener: (message: Message) => void): any;
    onSubscribe(listener: (message: Message) => void): any;
    onError(listener: (err: Error) => void): any;
}
//# sourceMappingURL=interface.d.ts.map