"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalEventBus = void 0;
const base_1 = require("./base");
class LocalDispatcher {
    constructor() {
        this.pidIdx = 0;
    }
    clear() {
        this.mainWorker = null;
        this.childWorker = null;
        this.pidIdx = 0;
    }
    generatePid() {
        return this.pidIdx++;
    }
}
const dispatcher = new LocalDispatcher();
class LocalWorker {
    constructor(pid) {
        this.pid = pid;
    }
    onMessage(handler) {
        this.handler = handler;
    }
    on() {
        // ignore exit event
    }
    getWorkerId() {
        return this.pid;
    }
    terminate() { }
}
class LocalEventBus extends base_1.AbstractEventBus {
    constructor(options) {
        super(options);
        this.worker = new LocalWorker(dispatcher.generatePid());
        if (this.isMain()) {
            this.debugLogger(`Main id=${this.worker.getWorkerId()}`);
            dispatcher.mainWorker = this.worker;
        }
        else {
            this.debugLogger(`Child id=${this.worker.getWorkerId()}`);
            dispatcher.childWorker = this.worker;
        }
    }
    workerSubscribeMessage(subscribeMessageHandler) {
        if (this.isWorker()) {
            dispatcher.childWorker.onMessage(subscribeMessageHandler);
        }
        else {
            dispatcher.mainWorker.onMessage(subscribeMessageHandler);
        }
    }
    workerListenMessage(worker, subscribeMessageHandler) {
        if (this.isWorker()) {
            dispatcher.childWorker.onMessage(subscribeMessageHandler);
        }
        else {
            dispatcher.mainWorker.onMessage(subscribeMessageHandler);
        }
    }
    workerSendMessage(message) {
        dispatcher.mainWorker.handler(message);
    }
    mainSendMessage(worker, message) {
        dispatcher.childWorker.handler(message);
    }
    getWorkerId(worker) {
        return String((worker || this.worker).getWorkerId());
    }
    isMain() {
        return !this.isWorker();
    }
    isWorker() {
        return this.options.isWorker;
    }
    async start() {
        if (this.isMain()) {
            this.addWorker(dispatcher.childWorker);
        }
        await super.start();
    }
    async stop() {
        dispatcher.clear();
        await super.stop();
    }
}
exports.LocalEventBus = LocalEventBus;
//# sourceMappingURL=local.js.map